@@ -60,6 +60,8 @@ DefaultAction.prototype.beginEvent = function() {
     this.setState(DefaultAction.State.Neutral);
     this.blockRefId = RObject.INVALID_ID;
     this.entityInBlockId = RObject.INVALID_ID;
+
+    this.optOutRelativeZeroResume = true;
 };
 
 DefaultAction.prototype.setState = function(state) {
@@ -80,6 +82,7 @@ DefaultAction.prototype.setState = function(state) {
         this.setArrowCursor();
     }
 
+    var tr;
     switch (this.state) {
     case DefaultAction.State.Neutral:
         this.d1Model = RVector.invalid;
@@ -99,21 +102,23 @@ DefaultAction.prototype.setState = function(state) {
         this.d2Screen = RVector.invalid;
         break;
     case DefaultAction.State.SettingCorner2:
-        this.setLeftMouseTip(qsTr("Set second corner"));
+        tr = qsTr("Second corner");
+        this.setLeftMouseTip(tr);
+        this.setCommandPrompt(tr);
         this.setRightMouseTip("");
         break;
     case DefaultAction.State.MovingReference:
     case DefaultAction.State.SettingReference:
-        this.setLeftMouseTip(
-                qsTr("Specify target point of reference point")
-        );
+        tr = qsTr("Target point of reference point");
+        this.setLeftMouseTip(tr);
+        this.setCommandPrompt(tr);
         this.setRightMouseTip("");
         break;
     case DefaultAction.State.MovingEntity:
     case DefaultAction.State.SettingEntity:
-        this.setLeftMouseTip(
-                qsTr("Specify target point of selection")
-        );
+        tr = qsTr("Target point of selection");
+        this.setLeftMouseTip(tr);
+        this.setCommandPrompt(tr);
         this.setRightMouseTip("");
         break;
     case DefaultAction.State.MovingEntityInBlock:
@@ -130,6 +135,8 @@ DefaultAction.prototype.suspendEvent = function() {
     if (!isNull(this.getGuiAction())) {
         this.getGuiAction().setChecked(false);
     }
+
+    EAction.prototype.suspendEvent.call(this);
 };
 
 DefaultAction.prototype.resumeEvent = function() {
@@ -319,7 +326,7 @@ DefaultAction.prototype.mouseReleaseEvent = function(event) {
             //qDebug("entityId: ", entityId);
 
             if (entityId !== -1) {
-                if (addToSelection && this.document.isSelected(entityId)) {
+                if (addToSelection && (this.document.isSelected(entityId) || this.document.isSelectedWorkingSet(entityId))) {
                     this.deselectEntity(entityId);
                 }
                 else {
@@ -431,15 +438,17 @@ DefaultAction.prototype.mousePressEvent = function(event) {
 };
 
 DefaultAction.prototype.mouseDoubleClickEvent = function(event) {
-    if (event.button() == Qt.LeftButton && this.state===DefaultAction.State.Neutral) {
+    if (event.button() == Qt.LeftButton && (this.state===DefaultAction.State.Neutral || this.state===DefaultAction.State.Dragging)) {
+        if (this.state===DefaultAction.State.Dragging) {
+            // cancel dragging (double-click):
+            this.setState(DefaultAction.State.Neutral);
+        }
         var view = event.getGraphicsView();
         var range = view.mapDistanceFromView(this.pickRangePixels);
         var strictRange = view.mapDistanceFromView(10);
         var entityId = this.di.getClosestEntity(event.getModelPosition(), range, strictRange, false);
         if (entityId===RObject.INVALID_ID) {
-            if (this.document.getCurrentViewportId()!==RObject.INVALID_ID) {
-                this.di.unsetCurrentViewport();
-            }
+            this.emptySpaceDoubleClicked();
             return;
         }
 
@@ -448,6 +457,12 @@ DefaultAction.prototype.mouseDoubleClickEvent = function(event) {
     EAction.prototype.mouseDoubleClickEvent.call(this, event);
 };
 
+DefaultAction.prototype.emptySpaceDoubleClicked = function() {
+    if (this.document.getCurrentViewportId()!==RObject.INVALID_ID) {
+        this.di.unsetCurrentViewport();
+    }
+};
+
 DefaultAction.prototype.escapeEvent = function(event) {
     this.di.clearPreview();
     this.di.repaintViews();
@@ -455,6 +470,11 @@ DefaultAction.prototype.escapeEvent = function(event) {
     this.setState(DefaultAction.State.Neutral);
 };
 
+DefaultAction.prototype.coordinateEvent = function(event) {
+    // required to make sure invalid coordinate event goes through (needed for drag and drop):
+    this.pickCoordinate(event, false);
+};
+
 DefaultAction.prototype.pickCoordinate = function(event, preview) {
     var op;
 
@@ -488,7 +508,7 @@ DefaultAction.prototype.pickCoordinate = function(event, preview) {
 
         if (preview) {
             this.d2Model = d2;
-            op = new RMoveReferencePointOperation(this.d1Model, this.d2Model);
+            op = new RMoveReferencePointOperation(this.d1Model, this.d2Model, event.getModifiers());
             var scene = this.di.getGraphicsSceneWithFocus();
             op.setGraphicsScene(scene);
             this.di.previewOperation(op);
@@ -499,7 +519,7 @@ DefaultAction.prototype.pickCoordinate = function(event, preview) {
             }
             else {
                 this.d2Model = d2;
-                op = new RMoveReferencePointOperation(this.d1Model, this.d2Model);
+                op = new RMoveReferencePointOperation(this.d1Model, this.d2Model, event.getModifiers());
                 var scene = this.di.getGraphicsSceneWithFocus();
                 op.setGraphicsScene(scene);
                 op.setText(qsTr("Move Reference Point"));
@@ -696,7 +716,13 @@ DefaultAction.prototype.entityDoubleClicked = function(entityId, event) {
 
         if (RSettings.getBoolValue("GraphicsView/DoubleClickSelectContour", true)===true) {
             include("scripts/Select/SelectContour/SelectContour.js");
-            var matchingEntityIds = SelectContour.getConnectedEntities(this.document, entityId, 0.001);
+            var tol = RSettings.getDoubleValue("GraphicsView/DoubleClickSelectContourTolerance", 0.001);
+            var layerId = RObject.INVALID_ID;
+            if (isAltPressed(event)) {
+                // Alt: restrict to same layer:
+                layerId = entity.getLayerId();
+            }
+            var matchingEntityIds = SelectContour.getConnectedEntities(this.document, entityId, tol, layerId);
             var add = isShiftPressed(event);
             if (entity.isSelected()) {
                 this.di.selectEntities(matchingEntityIds, add);
